====
smif
====

Simulation Modelling Integration Framework

.. image:: https://img.shields.io/badge/github-nismod%2Fsmif-brightgreen.svg
   :target: https://github.com/nismod/smif/
   :alt: nismod/smif on github

.. include:: ../README.rst
   :start-line: 8
   :end-line: 36


.. include:: ../README.rst
   :start-line: 36
   :end-line: 118


.. include:: ../README.rst
   :start-line: 241


Contents
========

.. toctree::
   :maxdepth: 2

   Installation <installation>
   Getting Started <getting_started>
   Concepts <concepts>
   Configuration <project_configuration>
   Adding a Model <simulation_models>

.. toctree::
   :maxdepth: 3

   Reference <api/modules>

.. toctree::
   :maxdepth: 1

   Developing `smif` <developers>
   Contributing <contributing>
   License <license>
   Authors <authors>
   Changelog <changelog>


Indexes and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
